@@ -20,10 +20,9 @@
 
 #include <qpushbutton.h>
 #include <q3process.h>
-//Added by qt3to4:
-#include <Q3TextStream>
-#include <Q3HBoxLayout>
-#include <Q3VBoxLayout>
+#include <QTextStream>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -40,7 +39,7 @@ using namespace std;
 AureportProcess::AureportProcess(QWidget *parent, const char *name): QDialog(parent, name)
 {
 	setCaption(tr("Aureport Process"));
-	textEdit1 = new Q3TextEdit(this);
+	textEdit1 = new QTextEdit(this);
 	textEdit1->setPaletteBackgroundColor(QColor(250,180,200));
         textEdit1->resize( 600, 100 );
 
@@ -49,9 +48,9 @@ AureportProcess::AureportProcess(QWidget *parent, const char *name): QDialog(par
 	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
 	closeButton->setDefault(true);
 
-	mainLayout = new Q3VBoxLayout(this);
-	upperLayout = new Q3VBoxLayout;
-	footLayout = new Q3HBoxLayout;
+	mainLayout = new QVBoxLayout(this);
+	upperLayout = new QVBoxLayout;
+	footLayout = new QHBoxLayout;
 	
 	mainLayout->setMargin(11);
 	upperLayout->addWidget(textEdit1);
@@ -117,7 +116,7 @@ void AureportProcess::readFromOutputFile(QString aureport_str_pp_str)
 			file_interface_name = dir_name + forward_slash + name;
 			QFile file( file_interface_name );
 			if ( file.open( QIODevice::ReadOnly ) ) {
-				Q3TextStream stream( &file );
+				QTextStream stream( &file );
 				////////////////////////////////////////////
 				//int i,j,k,l,m,n;	
 				if(order_x == 1)
@@ -128,7 +127,7 @@ void AureportProcess::readFromOutputFile(QString aureport_str_pp_str)
 					line_analized = stream.readLine(); // line of text excluding '\n'
 					textEdit1->append(line_analized);
 				}
-				textEdit1->setCursorPosition(0,0);
+				//textEdit1->setCursorPosition(0,0);//delete?
 				file.close();
 				order_x++;
 				++it_d;
