@@ -25,12 +25,15 @@
 #include <qlayout.h>
 #include <qdir.h> 
 #include <qlabel.h> 
-#include <q3textedit.h>
+//#include <q3textedit.h>//delete
 #include <q3buttongroup.h>
 #include <qradiobutton.h>
 //Added by qt3to4:
-#include <Q3VBoxLayout>
-#include <Q3HBoxLayout>
+//#include <Q3VBoxLayout>//replaced
+//#include <Q3HBoxLayout>//replaced
+#include <QVBoxLayout>
+#include <QHBoxLayout>
+#include <QTextEdit>
 
 class AureportProcess: public QDialog 
 {
@@ -46,11 +49,11 @@ private slots:
 public:
 private:
 	QPushButton *closeButton;
-	Q3TextEdit *textEdit1;
+	QTextEdit *textEdit1;
 
-	Q3VBoxLayout *mainLayout;
-	Q3VBoxLayout *upperLayout;
-	Q3HBoxLayout *footLayout;
+	QVBoxLayout *mainLayout;
+	QVBoxLayout *upperLayout;
+	QHBoxLayout *footLayout;
 
         QDir dir;
         QString path;
