@@ -26,22 +26,17 @@
 #include <qcheckbox.h>
 #include <qlabel.h> 
 //added by intrajp
-#include <q3button.h>
 #include <QButtonGroup>
 #include <QPushButton>
 #include <QGroupBox>
 
-//#include <q3buttongroup.h>
 #include <qradiobutton.h>
-//Added by qt3to4:
-//#include <Q3HBoxLayout>
-//#include <Q3VBoxLayout>
 #include <QHBoxLayout>
 #include <QVBoxLayout>
 
 
 class QLayout;
-class Q3TextEdit;
+class QTextEdit;
 class QLineEdit;
 class QPushButton;
 class AusearchProcess;
@@ -91,7 +86,7 @@ private:
 	QLineEdit *endtimeEditLineEdit;
 	QString ausearchEditLineEdit_str;
 	QPushButton *closeButton;
-	Q3TextEdit *textEdit1;
+	QTextEdit *textEdit1;
 
 	QHBoxLayout *mainLayout;
 	QVBoxLayout *rightLayout;
