@@ -67,7 +67,8 @@
 #include <q3textedit.h>
 //Added by qt3to4:
 #include <QPixmap>
-#include <Q3PopupMenu>
+///#include <Q3PopupMenu>//replaced
+#include <QMenu>
 #include <QCloseEvent>
 
 #include "editor.h"
@@ -110,6 +111,7 @@
 #include "segatex_booleannames.h"
 #include "segatex_getpidcon.h"
 #include "segatex_selinuxpath.h"
+#include "sepolicygenerate.h"
 #ifdef SEGATEX_VERSION
 #include "segatex_version.h"
 #endif
@@ -170,6 +172,7 @@
 	segatex_booleannames_o = 0;
 	segatex_getpidcon_o = 0;
 	segatex_selinuxpath_o = 0;
+	sepolicy_generate_o = 0;
 
 	createActions();
 	createMenus();
@@ -177,7 +180,7 @@
 	createStatusBar();
 	updateMenus();
 	readSettings();
-	setWindowTitle(tr("segatex-8.000"));
+	setWindowTitle(tr("segatex-8.500"));
 	QPixmap myIcon1 = QPixmap(":/images/icon.png");
 	this->setIcon(myIcon1);
 }
@@ -213,6 +216,7 @@ void MainWindow::createMenus()
 
 	policyMenu = menuBar()->addMenu(tr("&Policy"));
 	policyMenu->addAction(sqlrefpolicyAct);
+	policyMenu->addAction(sepolicy_generateAct);
 	policyMenu->addAction(selinuxYumAct);
 	policyMenu->addAction(enforcingAct);
 	policyMenu->addAction(check_selinuxAct);
@@ -365,6 +369,11 @@ void MainWindow::createActions()
 	connect(sqlrefpolicyAct, SIGNAL(activated()), this, SLOT(sqlrefpolicy()));
 	connect(sqlrefpolicyAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
+	sepolicy_generateAct = new QAction(tr("sepolicy &Generate "), this);
+	sepolicy_generateAct->setStatusTip(tr("sepolicy generate."));
+	connect(sepolicy_generateAct, SIGNAL(activated()), this, SLOT(sepolicy_generate()));
+	connect(sepolicy_generateAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
 	selinuxYumAct = new QAction(tr("&Yum install/update"), this);
 	selinuxYumAct->setStatusTip(tr("Yum install/update SELinux related RPMs."));
 	connect(selinuxYumAct, SIGNAL(activated()), this, SLOT(yum_selinux()));
@@ -628,10 +637,10 @@ void MainWindow::paste()
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-8.000</h2>"
+		tr("<h2>segatex-8.500</h2>"
 		"<p>Copyright &copy; 2007-2014"
 		"<p>Shintaro Fujiwara."
-		"<p>segatex is a SELinux tool"
+		"<p><a href=\"http://sourceforge.net/projects/segatex\">segatex</a> is a SELinux tool"
 		"<p><b>written with Qt</b>."));
 }
  void MainWindow::updateMenus()
@@ -1138,6 +1147,15 @@ void MainWindow::segatex_selinuxpath()
 	segatex_selinuxpath_o->raise();
 	segatex_selinuxpath_o->setActiveWindow();
 }
+void MainWindow::sepolicy_generate()
+{
+	if(!sepolicy_generate_o) {
+		sepolicy_generate_o = new SepolicyGenerate(this);
+	}
+	sepolicy_generate_o->show();
+	sepolicy_generate_o->raise();
+	sepolicy_generate_o->setActiveWindow();
+}
 void MainWindow::howtouse()
 {
 	QMessageBox::about(this, tr("How to use"),
