@@ -85,6 +85,8 @@ class SegatexClassaccessvector;
 class SegatexBooleannames;
 class SegatexGetpidcon;
 class SegatexSelinuxpath;
+class SepolicyGenerate;
+class SepolicyGenerateProcess;
 
 class MainWindow : public QMainWindow
 {
@@ -149,6 +151,7 @@ private slots:
 	void segatex_booleannames();
 	void segatex_getpidcon();
 	void segatex_selinuxpath();
+	void sepolicy_generate();
 private:
 	void createActions();
 	void createMenus();
@@ -238,6 +241,7 @@ private:
 	QAction *segatex_booleannamesAct;
 	QAction *segatex_getpidconAct;
 	QAction *segatex_selinuxpathAct;
+	QAction *sepolicy_generateAct;
 
 	QString selinux_policy;
 	QString enabled_or_not_str;
@@ -287,5 +291,6 @@ private:
 	SegatexBooleannames *segatex_booleannames_o;
 	SegatexGetpidcon *segatex_getpidcon_o;
 	SegatexSelinuxpath *segatex_selinuxpath_o;
+	SepolicyGenerate *sepolicy_generate_o;
 };
 #endif
