@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2013 Shintaro Fujiwara 
+ * Copyright (C) 2007-2014 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include <qregexp.h>
 #include <qdialog.h>
 #include <q3textedit.h>
+#include <qlabel.h>
 
 
 class QLayout;
@@ -48,6 +49,7 @@ private slots:
 	void yum_clicked();
 	unsigned long getuid_uid_value();//unused
 private:
+	QLabel *packagesLabel;
 	QCheckBox *targetedCheckBox;
 	QCheckBox *minimalCheckBox;
 	QCheckBox *permissiveCheckBox;
