@@ -27,7 +27,7 @@
 using namespace std;
 //
 
-//default constructor
+//constructor
 Sqlrefpolicy::Sqlrefpolicy(QWidget *parent, const char *name): QDialog(parent, name)
 {
 	targetdomainEditLineEdit = new QLineEdit(this );
@@ -112,7 +112,6 @@ void Sqlrefpolicy::targetdomain_clicked()
 }
 void Sqlrefpolicy::segatex_core2_next_denied_message_button_clicked()
 {
-	//targetdomain_clicked();
 	permissions_pre_main_str = av.value(i_pub++);
 	permissionsEditLineEdit->setText(permissions_pre_main_str);
 }
@@ -123,48 +122,8 @@ void Sqlrefpolicy::segatex_core2_prev_denied_message_button_clicked()
 }
 void Sqlrefpolicy::segatex_core2_process_sql(const QList<QString> &l, const QList<QString> &l2, const QList<QString> &l3, const QList<QString> &l4)
 {
-	//permissions_pre_main_str = permissionsEditLineEdit->text();
 	av = l4;
 	i_pub = 0;
 	permissions_pre_main_str = av.first();
 	permissionsEditLineEdit->setText(permissions_pre_main_str);
 }
-/*
-void Sqlrefpolicy::segatex_core2_process_sql(const QList<QString> &l, const QList<QString> &l2, const QList<QString> &l3, const QList<QString> &l4)
-{
-
-	//QListIterator<QString> javaStyleIterator(l4);
-	//while (javaStyleIterator.hasNext())
-	//{
-		//l4 = javaStyleIterator.next();
-
-	//targetdomain_pre_main_str = l2.last();
-	targetdomain_pre_main_str = "";
-	targetdomain_pre_first_str = "target_domain like '%";
-	targetdomain_pre_last_str = "%'";
-	objectclass_pre_main_str = l3.last();
-	//objectclass_pre_main_str = l3.front();
-	objectclass_pre_first_str = "object_class like '%";
-	objectclass_pre_last_str = "%'";
-	permissions_pre_main_str = l4.last();
-	//permissions_pre_main_str = l4.front();
-	permissions_pre_first_str = "permissions like '%";
-	permissions_pre_last_str = "%'";
-
-	targetdomain_objectclass_str += targetdomain_pre_first_str + targetdomain_pre_main_str + targetdomain_pre_last_str + " and " + objectclass_pre_first_str + objectclass_pre_main_str + objectclass_pre_last_str + " and " + permissions_pre_first_str + permissions_pre_main_str + permissions_pre_last_str;
-	//targetdomain_objectclass_str += targetdomain_pre_first_str + targetdomain_pre_main_str + targetdomain_pre_last_str + " and " + objectclass_pre_first_str + objectclass_pre_main_str + objectclass_pre_last_str + " and " + permissions_pre_first_str + permissions_pre_main_str + permissions_pre_last_str + " union ";
-
-	model->setTable("layer_if_file_interface_name_target_domain_object_class_permissions");
-	model->setEditStrategy(QSqlTableModel::OnManualSubmit);
-	model->removeColumn(0);
-	model->setHeaderData(0, Qt::Horizontal, tr("Layer"));
-	model->setHeaderData(1, Qt::Horizontal, tr("If file"));
-	model->setHeaderData(2, Qt::Horizontal, tr("Interface Name"));
-	model->setHeaderData(3, Qt::Horizontal, tr("Target Domain"));
-	model->setHeaderData(4, Qt::Horizontal, tr("Object Class"));
-	model->setHeaderData(5, Qt::Horizontal, tr("Permissions"));
-	model->setFilter(targetdomain_objectclass_str);
-	model->select();
-	//}
-}
-*/
